@@ -1,3 +1,5 @@
+# -*- Perl -*-
+#
 # http://www.lilypond.org/ related utility code (mostly to transition
 # between Perl processing integers and the related appropriate letter
 # names for the black dots in lilypond).
@@ -10,7 +12,7 @@ use warnings;
 use Carp qw(croak);
 use Scalar::Util qw(blessed looks_like_number);
 
-our $VERSION = '0.40';
+our $VERSION = '0.43';
 
 # Since dealing with lilypond, assume 12 pitch material
 my $DEG_IN_SCALE = 12;
@@ -365,7 +367,7 @@ sub mode {
       my $range_result;
       eval { $range_result = $self->_range_check($pitch); };
       croak $@ if $@;
-      if (defined $range_result) {
+      if ( defined $range_result ) {
         push @notes, $range_result;
         next;
       }
@@ -425,14 +427,16 @@ sub _range_check {
   my ( $self, $pitch ) = @_;
   if ( $pitch < $self->{_min_pitch} ) {
     if ( exists $self->{_min_pitch_hook} ) {
-      return $self->{_min_pitch_hook}($pitch);
+      return $self->{_min_pitch_hook}( $pitch, $self->{_min_pitch},
+        $self->{_max_pitch}, $self );
     } else {
       die "pitch $pitch is too low\n";
     }
 
   } elsif ( $pitch > $self->{_max_pitch} ) {
     if ( exists $self->{_max_pitch_hook} ) {
-      return $self->{_max_pitch_hook}($pitch);
+      return $self->{_max_pitch_hook}( $pitch, $self->{_min_pitch},
+        $self->{_max_pitch}, $self );
     } else {
       die "pitch $pitch is too high\n";
     }
@@ -582,11 +586,12 @@ easily be generated from those...so 0 is the minimum.
 =item *
 
 B<min_pitch_hook> code reference to handle minimum pitch cases instead
-of the default exception. The hook is passed the pitch as the sole
-argument, and should return C<undef> if the value is to be accepted, or
-something not defined to use that instead, or could throw an exception,
-which will be re-thrown via C<croak>. One approach would be to silence
-the out-of-bounds pitches by returning a lilypond rest symbol:
+of the default exception. The hook is passed the pitch, min_pitch,
+max_pitch, and the object itself as arguments. The hook must return
+C<undef> if the value is to be accepted, or something not defined to use
+that instead, or could throw an exception, which will be re-thrown via
+C<croak>. One approach would be to silence the out-of-bounds pitches by
+returning a lilypond rest symbol:
 
   Music::LilyPondUtil->new( min_pitch_hook => sub { 'r' } );
 
@@ -604,12 +609,9 @@ to by default throw an exception.
 =item *
 
 B<max_pitch_hook> code reference to handle minimum pitch cases instead
-of the default exception. For details see B<min_pitch_hook>, above. For
-another example, return the empty string if the maximum pitch is
-exceeded; this differs from replacing the note with a C<r> or C<s>,
-which in lilypond both advance the time by some duration.
-
-  Music::LilyPondUtil->new( max_pitch_hook => sub { '' } );
+of the default exception. The hook is passed the pitch, min_pitch,
+max_pitch, and the object itself as arguments. Return values are handled
+as for the B<min_pitch_hook>, above.
 
 =item *
 
@@ -759,7 +761,7 @@ function, and omit the notes if they fall outside a particular range.
 This method requires the use of a graphing calculator, knowledge of
 various mathematical functions, and spare time, though may produce
 interesting results, depending on how the function(s) interact with the
-playable range.
+playable range. This example strips pitches that exceed the limits:
 
   use Music::LilyPondUtil ();
   my $lyu = Music::LilyPondUtil->new(
@@ -790,28 +792,37 @@ L<App::MusicTools>, for example if saved as C<domath>:
 
 Which in turn would require C<lilypond>, a PDF viewer, and a MIDI player.
 
+This more complicated example uses the C<reflect_pitch> method of
+L<Music::AtonalUtil> to fold out-of-bounds pitches to within the limits:
+
+  use Music::AtonalUtil;
+  use Music::LilyPondUtil;
+
+  my $atu = Music::AtonalUtil->new;
+  my $lyu = Music::LilyPondUtil->new(
+    min_pitch      => 59,
+    max_pitch      => 79,
+    min_pitch_hook => \&fold,
+    max_pitch_hook => \&fold,
+  );
+
+  sub fold {
+    my ($p, $min, $max, $self) = @_;
+    return $self->p2ly( $atu->reflect_pitch( $p, $min, $max ) );
+  }
+
 =head1 SEE ALSO
 
-=over 4
-
-=item *
-
-http://www.lilypond.org/ and most notably the Learning and
+L<http://www.lilypond.org/> and most notably the Learning and
 Notation manuals.
 
-=item *
-
-L<App::MusicTools> whose command line tools make use of this module.
-
-=back
-
 =head1 AUTHOR
 
 Jeremy Mates, E<lt>jmates@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2012 by Jeremy Mates
+Copyright (C) 2012-2013 by Jeremy Mates
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself, either Perl version 5.16 or, at
